# snake-amh

[![PyPI - Version](https://img.shields.io/pypi/v/snake-amh.svg)](https://pypi.org/project/snake-amh)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/snake-amh.svg)](https://pypi.org/project/snake-amh)

-----

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## Installation

```bash
pipx install snake-amh
```

If you do not have `pipx` installed you can learn how to install it [here](https://github.com/pypa/pipx).

## Usage
After installing `snake-amh` via `pipx` you can play the game by simply running `snake` from your terminal of choice.

Note: To quit the game you can enter `^p` and select "Quit the application".


## License

`snake-amh` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
